diff --git a/.editorconfig b/.editorconfig
index ec2a1638..8bbdc9ca 100644
--- a/.editorconfig
+++ b/.editorconfig
@@ -1,4 +1,4 @@
-// Avoid looking for .editorconfig files in parent directories
+# Avoid looking for .editorconfig files in parent directories
root=true
[*]
@@ -7,6 +7,9 @@ insert_final_newline = true
indent_style = space
indent_size = 4
tab_width = 4
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = exclusion.dic
+spelling_checkable_types = all
[*.{xml,csproj,props}]
@@ -776,14 +779,14 @@ dotnet_diagnostic.IDE0032.severity = suggestion
dotnet_diagnostic.IDE0045.severity = none
# IDE0046: Use conditional expression for return
-#
+#
# Using a conditional expression is not always a clear win for readability.
#
# Configured using 'dotnet_style_prefer_conditional_expression_over_return'
dotnet_diagnostic.IDE0046.severity = suggestion
# IDE0047: Remove unnecessary parentheses
-#
+#
# Removing "unnecessary" parentheses is not always a clear win for readability.
dotnet_diagnostic.IDE0047.severity = suggestion
@@ -794,7 +797,7 @@ dotnet_diagnostic.IDE0047.severity = suggestion
dotnet_diagnostic.IDE0130.severity = none
# IDE0270: Null check can be simplified
-#
+#
# var inputPath = originalDossierPathList.Find(x => x.id == updatedPath.id);
# if (inputPath is null)
# {
@@ -938,7 +941,7 @@ csharp_new_line_before_catch = true
csharp_new_line_before_finally = true
# Enabling this setting breaks Resharper formatting for an enum field reference that is
# deeply nested in an object initializer.
-#
+#
# For an example, see TDataExchangeGeneralEnricher_CernInfrastructureObstruction.
#csharp_new_line_before_members_in_object_initializers = true
csharp_new_line_before_members_in_anonymous_types = true
@@ -1021,19 +1024,19 @@ dotnet_naming_rule.private_const_fields_pascal_case.severity = warning
dotnet_naming_symbols.interface.applicable_kinds = interface
dotnet_naming_symbols.interface.applicable_accessibilities = *
-dotnet_naming_symbols.interface.required_modifiers =
+dotnet_naming_symbols.interface.required_modifiers =
dotnet_naming_symbols.types.applicable_kinds = class, struct, interface, enum
dotnet_naming_symbols.types.applicable_accessibilities = *
-dotnet_naming_symbols.types.required_modifiers =
+dotnet_naming_symbols.types.required_modifiers =
dotnet_naming_symbols.non_field_members.applicable_kinds = property, event, method
dotnet_naming_symbols.non_field_members.applicable_accessibilities = *
-dotnet_naming_symbols.non_field_members.required_modifiers =
+dotnet_naming_symbols.non_field_members.required_modifiers =
dotnet_naming_symbols.private_fields.applicable_kinds = field
dotnet_naming_symbols.private_fields.applicable_accessibilities = private
-dotnet_naming_symbols.private_fields.required_modifiers =
+dotnet_naming_symbols.private_fields.required_modifiers =
dotnet_naming_symbols.private_static_fields.applicable_kinds = field
dotnet_naming_symbols.private_static_fields.applicable_accessibilities = private
@@ -1050,18 +1053,18 @@ dotnet_naming_symbols.private_const_fields.required_modifiers = const
# Naming styles
dotnet_naming_style.begins_with_i.required_prefix = I
-dotnet_naming_style.begins_with_i.required_suffix =
-dotnet_naming_style.begins_with_i.word_separator =
+dotnet_naming_style.begins_with_i.required_suffix =
+dotnet_naming_style.begins_with_i.word_separator =
dotnet_naming_style.begins_with_i.capitalization = pascal_case
-dotnet_naming_style.pascal_case.required_prefix =
-dotnet_naming_style.pascal_case.required_suffix =
-dotnet_naming_style.pascal_case.word_separator =
+dotnet_naming_style.pascal_case.required_prefix =
+dotnet_naming_style.pascal_case.required_suffix =
+dotnet_naming_style.pascal_case.word_separator =
dotnet_naming_style.pascal_case.capitalization = pascal_case
dotnet_naming_style.camel_case_begins_with_underscore.required_prefix = _
-dotnet_naming_style.camel_case_begins_with_underscore.required_suffix =
-dotnet_naming_style.camel_case_begins_with_underscore.word_separator =
+dotnet_naming_style.camel_case_begins_with_underscore.required_suffix =
+dotnet_naming_style.camel_case_begins_with_underscore.word_separator =
dotnet_naming_style.camel_case_begins_with_underscore.capitalization = camel_case
#### .NET Compiler Platform general options ####
diff --git a/Renci.SshNet.sln b/Renci.SshNet.sln
index 4a0a2053..f4045708 100644
--- a/Renci.SshNet.sln
+++ b/Renci.SshNet.sln
@@ -14,6 +14,7 @@ Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Solution Items", "Solution
CONTRIBUTING.md = CONTRIBUTING.md
Directory.Build.props = Directory.Build.props
Directory.Packages.props = Directory.Packages.props
+ exclusion.dic = exclusion.dic
global.json = global.json
LICENSE = LICENSE
nuget.config = nuget.config
diff --git a/exclusion.dic b/exclusion.dic
new file mode 100644
index 00000000..95df49b0
--- /dev/null
+++ b/exclusion.dic
@@ -0,0 +1,53 @@
+args
+atime
+bcrypt
+bigint
+bourne
+cbc
+chacha
+csproj
+decryptor
+dest
+diffie
+docfx
+ecdh
+ecdsa
+emerle
+exe
+fallback
+github
+hmac
+hostbased
+identd
+ietf
+impl
+infocmp
+kewl
+kex
+mindrot
+mtime
+netconf
+nist
+nistp
+openssh
+pkcs
+posix
+privatekey
+protoversion
+pubkey
+publickey
+renci
+ripemd
+slen
+sntrup
+softwareversion
+sshd
+tcpip
+threadpool
+umac
+unpad
+unix
+waithandle
+xoff
+xmldoc
+zlib
diff --git a/src/Renci.SshNet/.editorconfig b/src/Renci.SshNet/.editorconfig
index ee5bc33b..59be614a 100644
--- a/src/Renci.SshNet/.editorconfig
+++ b/src/Renci.SshNet/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../exclusion.dic
+spelling_checkable_types = all
#### Sonar rules ####
diff --git a/src/Renci.SshNet/Abstractions/SocketAbstraction.cs b/src/Renci.SshNet/Abstractions/SocketAbstraction.cs
index 7114247a..69ec38b2 100644
--- a/src/Renci.SshNet/Abstractions/SocketAbstraction.cs
+++ b/src/Renci.SshNet/Abstractions/SocketAbstraction.cs
@@ -350,7 +350,7 @@ namespace Renci.SshNet.Abstractions
}
else
{
- throw; // any serious error occurr
+ throw; // any serious error occur
}
}
}
diff --git a/src/Renci.SshNet/BaseClient.cs b/src/Renci.SshNet/BaseClient.cs
index d855c734..d799abab 100644
--- a/src/Renci.SshNet/BaseClient.cs
+++ b/src/Renci.SshNet/BaseClient.cs
@@ -408,7 +408,7 @@ namespace Renci.SshNet
{
}
- private void Session_ErrorOccured(object? sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object? sender, ExceptionEventArgs e)
{
ErrorOccurred?.Invoke(this, e);
}
@@ -558,7 +558,7 @@ namespace Renci.SshNet
var session = _serviceFactory.CreateSession(ConnectionInfo, _serviceFactory.CreateSocketFactory());
session.ServerIdentificationReceived += Session_ServerIdentificationReceived;
session.HostKeyReceived += Session_HostKeyReceived;
- session.ErrorOccured += Session_ErrorOccured;
+ session.ErrorOccured += Session_ErrorOccurred;
try
{
@@ -577,7 +577,7 @@ namespace Renci.SshNet
var session = _serviceFactory.CreateSession(ConnectionInfo, _serviceFactory.CreateSocketFactory());
session.ServerIdentificationReceived += Session_ServerIdentificationReceived;
session.HostKeyReceived += Session_HostKeyReceived;
- session.ErrorOccured += Session_ErrorOccured;
+ session.ErrorOccured += Session_ErrorOccurred;
try
{
@@ -593,7 +593,7 @@ namespace Renci.SshNet
private void DisposeSession(ISession session)
{
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
session.HostKeyReceived -= Session_HostKeyReceived;
session.ServerIdentificationReceived -= Session_ServerIdentificationReceived;
session.Dispose();
diff --git a/src/Renci.SshNet/Channels/Channel.cs b/src/Renci.SshNet/Channels/Channel.cs
index bbcd1ffb..29a50652 100644
--- a/src/Renci.SshNet/Channels/Channel.cs
+++ b/src/Renci.SshNet/Channels/Channel.cs
@@ -94,7 +94,7 @@ namespace Renci.SshNet.Channels
session.ChannelRequestReceived += OnChannelRequest;
session.ChannelSuccessReceived += OnChannelSuccess;
session.ChannelFailureReceived += OnChannelFailure;
- session.ErrorOccured += Session_ErrorOccured;
+ session.ErrorOccured += Session_ErrorOccurred;
session.Disconnected += Session_Disconnected;
}
@@ -102,7 +102,7 @@ namespace Renci.SshNet.Channels
/// Gets the session.
///
///
- /// Thhe session.
+ /// The session.
///
protected ISession Session
{
@@ -328,7 +328,7 @@ namespace Renci.SshNet.Channels
/// multiple chunks and will wait for the remote window size to be adjusted when it's zero.
///
///
- /// This is done to support SSH servers will a small window size that do not agressively
+ /// This is done to support SSH servers will a small window size that do not aggressively
/// increase their window size. We need to take into account that there may be SSH servers
/// that only increase their window size when it has reached zero.
///
@@ -586,7 +586,7 @@ namespace Renci.SshNet.Channels
{
}
- protected virtual void OnErrorOccured(Exception exp)
+ protected virtual void OnErrorOccurred(Exception exp)
{
}
@@ -609,20 +609,20 @@ namespace Renci.SshNet.Channels
///
/// The .
///
- /// This method will in turn invoke , and
+ /// This method will in turn invoke , and
/// raise the event.
///
protected void OnChannelException(Exception ex)
{
- OnErrorOccured(ex);
+ OnErrorOccurred(ex);
RaiseExceptionEvent(ex);
}
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
try
{
- OnErrorOccured(e.Exception);
+ OnErrorOccurred(e.Exception);
}
catch (Exception ex)
{
@@ -854,7 +854,7 @@ namespace Renci.SshNet.Channels
session.ChannelRequestReceived -= OnChannelRequest;
session.ChannelSuccessReceived -= OnChannelSuccess;
session.ChannelFailureReceived -= OnChannelFailure;
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
session.Disconnected -= Session_Disconnected;
}
diff --git a/src/Renci.SshNet/Channels/ChannelDirectTcpip.cs b/src/Renci.SshNet/Channels/ChannelDirectTcpip.cs
index 64f35d4a..140e5d6e 100644
--- a/src/Renci.SshNet/Channels/ChannelDirectTcpip.cs
+++ b/src/Renci.SshNet/Channels/ChannelDirectTcpip.cs
@@ -249,9 +249,9 @@ namespace Renci.SshNet.Channels
/// Called whenever an unhandled occurs in causing
/// the message loop to be interrupted, or when an exception occurred processing a channel message.
///
- protected override void OnErrorOccured(Exception exp)
+ protected override void OnErrorOccurred(Exception exp)
{
- base.OnErrorOccured(exp);
+ base.OnErrorOccurred(exp);
// signal to the client that we will not send anything anymore; this will also interrupt the
// blocking receive in Bind if the client sends FIN/ACK in time
@@ -261,7 +261,7 @@ namespace Renci.SshNet.Channels
}
///
- /// Called when the server wants to terminate the connection immmediately.
+ /// Called when the server wants to terminate the connection immediately.
///
///
/// The sender MUST NOT send or receive any data after this message, and
diff --git a/src/Renci.SshNet/Channels/ChannelForwardedTcpip.cs b/src/Renci.SshNet/Channels/ChannelForwardedTcpip.cs
index 10d8a161..18d5e2b4 100644
--- a/src/Renci.SshNet/Channels/ChannelForwardedTcpip.cs
+++ b/src/Renci.SshNet/Channels/ChannelForwardedTcpip.cs
@@ -98,9 +98,9 @@ namespace Renci.SshNet.Channels
SocketAbstraction.ReadContinuous(_socket, buffer, 0, buffer.Length, SendData);
}
- protected override void OnErrorOccured(Exception exp)
+ protected override void OnErrorOccurred(Exception exp)
{
- base.OnErrorOccured(exp);
+ base.OnErrorOccurred(exp);
// signal to the server that we will not send anything anymore; this will also interrupt the
// blocking receive in Bind if the server sends FIN/ACK in time
diff --git a/src/Renci.SshNet/Channels/ChannelSession.cs b/src/Renci.SshNet/Channels/ChannelSession.cs
index cb8bedc6..47442d7b 100644
--- a/src/Renci.SshNet/Channels/ChannelSession.cs
+++ b/src/Renci.SshNet/Channels/ChannelSession.cs
@@ -35,7 +35,7 @@ namespace Renci.SshNet.Channels
private EventWaitHandle _channelRequestResponse = new ManualResetEvent(initialState: false);
- private bool _channelRequestSucces;
+ private bool _channelRequestSuccess;
///
/// Initializes a new instance of the class.
@@ -136,7 +136,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new PseudoTerminalRequestInfo(environmentVariable, columns, rows, width, height, terminalModeValues)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -154,7 +154,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new X11ForwardingRequestInfo(isSingleConnection, protocol, cookie, screenNumber)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -170,7 +170,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new EnvironmentVariableRequestInfo(variableName, variableValue)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -184,7 +184,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new ShellRequestInfo()));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -199,7 +199,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new ExecRequestInfo(command, ConnectionInfo.Encoding)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -214,7 +214,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new BreakRequestInfo(breakLength)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -229,7 +229,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new SubsystemRequestInfo(subsystem)));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -277,7 +277,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new EndOfWriteRequestInfo()));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -291,7 +291,7 @@ namespace Renci.SshNet.Channels
_ = _channelRequestResponse.Reset();
SendMessage(new ChannelRequestMessage(RemoteChannelNumber, new KeepAliveRequestInfo()));
WaitOnHandle(_channelRequestResponse);
- return _channelRequestSucces;
+ return _channelRequestSuccess;
}
///
@@ -301,7 +301,7 @@ namespace Renci.SshNet.Channels
{
base.OnSuccess();
- _channelRequestSucces = true;
+ _channelRequestSuccess = true;
_ = _channelRequestResponse?.Set();
}
@@ -312,7 +312,7 @@ namespace Renci.SshNet.Channels
{
base.OnFailure();
- _channelRequestSucces = false;
+ _channelRequestSuccess = false;
_ = _channelRequestResponse?.Set();
}
diff --git a/src/Renci.SshNet/Channels/IChannel.cs b/src/Renci.SshNet/Channels/IChannel.cs
index f89679eb..4e15c6c4 100644
--- a/src/Renci.SshNet/Channels/IChannel.cs
+++ b/src/Renci.SshNet/Channels/IChannel.cs
@@ -102,7 +102,7 @@ namespace Renci.SshNet.Channels
/// multiple chunks and will wait for the remote window size to be adjusted when it's zero.
///
///
- /// This is done to support SSH servers will a small window size that do not agressively
+ /// This is done to support SSH servers will a small window size that do not aggressively
/// increase their window size. We need to take into account that there may be SSH servers
/// that only increase their window size when it has reached zero.
///
diff --git a/src/Renci.SshNet/ClientAuthentication.cs b/src/Renci.SshNet/ClientAuthentication.cs
index ad755be8..bd386ed2 100644
--- a/src/Renci.SshNet/ClientAuthentication.cs
+++ b/src/Renci.SshNet/ClientAuthentication.cs
@@ -116,7 +116,7 @@ namespace Renci.SshNet
foreach (var authenticationMethod in authenticationState.GetActiveAuthenticationMethods(matchingAuthenticationMethods))
{
- // guard against a stack overlow for servers that do not update the list of allowed authentication
+ // guard against a stack overflow for servers that do not update the list of allowed authentication
// methods after a partial success
if (authenticationState.GetPartialSuccessCount(authenticationMethod) >= _partialSuccessLimit)
{
diff --git a/src/Renci.SshNet/Common/ExceptionEventArgs.cs b/src/Renci.SshNet/Common/ExceptionEventArgs.cs
index 7e99def5..b183f998 100644
--- a/src/Renci.SshNet/Common/ExceptionEventArgs.cs
+++ b/src/Renci.SshNet/Common/ExceptionEventArgs.cs
@@ -3,7 +3,7 @@
namespace Renci.SshNet.Common
{
///
- /// Provides data for the ErrorOccured events.
+ /// Provides data for the ErrorOccurred events.
///
public class ExceptionEventArgs : EventArgs
{
diff --git a/src/Renci.SshNet/Common/SshDataStream.cs b/src/Renci.SshNet/Common/SshDataStream.cs
index af8be81b..a13b635e 100644
--- a/src/Renci.SshNet/Common/SshDataStream.cs
+++ b/src/Renci.SshNet/Common/SshDataStream.cs
@@ -213,7 +213,7 @@ namespace Renci.SshNet.Common
}
///
- /// Reads a from the SSH datastream.
+ /// Reads a from the SSH data stream.
///
///
/// The read from the SSH data stream.
diff --git a/src/Renci.SshNet/Connection/Socks5Connector.cs b/src/Renci.SshNet/Connection/Socks5Connector.cs
index a548eaea..bf54c228 100644
--- a/src/Renci.SshNet/Connection/Socks5Connector.cs
+++ b/src/Renci.SshNet/Connection/Socks5Connector.cs
@@ -180,7 +180,7 @@ namespace Renci.SshNet.Connection
var index = 0;
- // Version of the negiotiation
+ // Version of the negotiation
authenticationRequest[index++] = 0x01;
// Length of the username
diff --git a/src/Renci.SshNet/ForwardedPortDynamic.cs b/src/Renci.SshNet/ForwardedPortDynamic.cs
index 4a85a0fa..b86506c9 100644
--- a/src/Renci.SshNet/ForwardedPortDynamic.cs
+++ b/src/Renci.SshNet/ForwardedPortDynamic.cs
@@ -171,7 +171,7 @@ namespace Renci.SshNet
// update bound port (in case original was passed as zero)
BoundPort = (uint)((IPEndPoint)_listener.LocalEndPoint).Port;
- Session.ErrorOccured += Session_ErrorOccured;
+ Session.ErrorOccured += Session_ErrorOccurred;
Session.Disconnected += Session_Disconnected;
// consider port started when we're listening for inbound connections
@@ -401,7 +401,7 @@ namespace Renci.SshNet
var session = Session;
if (session is not null)
{
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
session.Disconnected -= Session_Disconnected;
}
}
@@ -449,7 +449,7 @@ namespace Renci.SshNet
}
}
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
var session = Session;
if (session is not null)
diff --git a/src/Renci.SshNet/ForwardedPortLocal.cs b/src/Renci.SshNet/ForwardedPortLocal.cs
index 50d84dc7..f5d37617 100644
--- a/src/Renci.SshNet/ForwardedPortLocal.cs
+++ b/src/Renci.SshNet/ForwardedPortLocal.cs
@@ -199,7 +199,7 @@ namespace Renci.SshNet
// update bound port (in case original was passed as zero)
BoundPort = (uint)((IPEndPoint)_listener.LocalEndPoint).Port;
- Session.ErrorOccured += Session_ErrorOccured;
+ Session.ErrorOccured += Session_ErrorOccurred;
Session.Disconnected += Session_Disconnected;
InitializePendingChannelCountdown();
@@ -375,7 +375,7 @@ namespace Renci.SshNet
var session = Session;
if (session != null)
{
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
session.Disconnected -= Session_Disconnected;
}
}
@@ -423,7 +423,7 @@ namespace Renci.SshNet
}
}
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
var session = Session;
if (session is not null)
diff --git a/src/Renci.SshNet/IServiceFactory.cs b/src/Renci.SshNet/IServiceFactory.cs
index c042e545..7051942a 100644
--- a/src/Renci.SshNet/IServiceFactory.cs
+++ b/src/Renci.SshNet/IServiceFactory.cs
@@ -121,7 +121,7 @@ namespace Renci.SshNet
///
///
/// The TERM environment variable contains an identifier for the text window's capabilities.
- /// You can get a detailed list of these cababilities by using the ‘infocmp’ command.
+ /// You can get a detailed list of these capabilities by using the ‘infocmp’ command.
///
///
/// The column/row dimensions override the pixel dimensions(when non-zero). Pixel dimensions refer
diff --git a/src/Renci.SshNet/ISubsystemSession.cs b/src/Renci.SshNet/ISubsystemSession.cs
index 4fa6b28b..ce9e4f1f 100644
--- a/src/Renci.SshNet/ISubsystemSession.cs
+++ b/src/Renci.SshNet/ISubsystemSession.cs
@@ -42,7 +42,7 @@ namespace Renci.SshNet
/// Waits a specified time for a given to get signaled.
///
/// The handle to wait for.
- /// The number of millieseconds wait for to get signaled, or -1 to wait indefinitely.
+ /// The number of milliseconds wait for to get signaled, or -1 to wait indefinitely.
/// The connection was closed by the server.
/// The channel was closed.
/// The handle did not get signaled within the specified timeout.
@@ -105,7 +105,7 @@ namespace Renci.SshNet
///
/// The connection was closed by the server.
/// The channel was closed.
- /// No object satified the wait and a time interval equivalent to has passed.
+ /// No object satisfied the wait and a time interval equivalent to has passed.
///
/// For the return value, the index of the first non-system object is considered to be zero.
///
diff --git a/src/Renci.SshNet/Messages/Connection/ChannelOpen/ChannelOpenMessage.cs b/src/Renci.SshNet/Messages/Connection/ChannelOpen/ChannelOpenMessage.cs
index a9d62b01..bd5c52bf 100644
--- a/src/Renci.SshNet/Messages/Connection/ChannelOpen/ChannelOpenMessage.cs
+++ b/src/Renci.SshNet/Messages/Connection/ChannelOpen/ChannelOpenMessage.cs
@@ -93,7 +93,7 @@ namespace Renci.SshNet.Messages.Connection
///
public ChannelOpenMessage()
{
- // Required for dynamicly loading request type when it comes from the server
+ // Required for dynamically loading request type when it comes from the server
}
///
diff --git a/src/Renci.SshNet/Messages/Connection/ChannelRequest/PseudoTerminalRequestInfo.cs b/src/Renci.SshNet/Messages/Connection/ChannelRequest/PseudoTerminalRequestInfo.cs
index e90bac45..33e46545 100644
--- a/src/Renci.SshNet/Messages/Connection/ChannelRequest/PseudoTerminalRequestInfo.cs
+++ b/src/Renci.SshNet/Messages/Connection/ChannelRequest/PseudoTerminalRequestInfo.cs
@@ -105,7 +105,7 @@ namespace Renci.SshNet.Messages.Connection
///
///
/// The TERM environment variable contains an identifier for the text window's capabilities.
- /// You can get a detailed list of these cababilities by using the ‘infocmp’ command.
+ /// You can get a detailed list of these capabilities by using the ‘infocmp’ command.
///
///
/// The column/row dimensions override the pixel dimensions(when nonzero). Pixel dimensions refer
diff --git a/src/Renci.SshNet/PrivateKeyFile.OpenSSH.cs b/src/Renci.SshNet/PrivateKeyFile.OpenSSH.cs
index 379b51cb..0a02d8cf 100644
--- a/src/Renci.SshNet/PrivateKeyFile.OpenSSH.cs
+++ b/src/Renci.SshNet/PrivateKeyFile.OpenSSH.cs
@@ -66,7 +66,7 @@ namespace Renci.SshNet
throw new SshException("At this time only one public key in the openssh key is supported.");
}
- // read public key in ssh-format, but we dont need it
+ // read public key in ssh-format, but we don't need it
_ = keyReader.ReadString(Encoding.UTF8);
// possibly encrypted private key
diff --git a/src/Renci.SshNet/RemotePathShellQuoteTransformation.cs b/src/Renci.SshNet/RemotePathShellQuoteTransformation.cs
index adc1442e..d019547b 100644
--- a/src/Renci.SshNet/RemotePathShellQuoteTransformation.cs
+++ b/src/Renci.SshNet/RemotePathShellQuoteTransformation.cs
@@ -118,7 +118,7 @@ namespace Renci.SshNet
break;
case '!':
/*
- * In C-Shell, an exclamatation point can only be protected from shell interpretation
+ * In C-Shell, an exclamation point can only be protected from shell interpretation
* when escaped by a backslash.
*
* Source:
diff --git a/src/Renci.SshNet/Security/Certificate.cs b/src/Renci.SshNet/Security/Certificate.cs
index 24cd1f1e..ccc358fc 100644
--- a/src/Renci.SshNet/Security/Certificate.cs
+++ b/src/Renci.SshNet/Security/Certificate.cs
@@ -176,7 +176,7 @@ namespace Renci.SshNet.Security
/// The key identifies the option and the value encodes
/// option-specific information.
/// All such options are "critical" in the sense that an implementation
- /// must refuse to authorise a key that has an unrecognised option.
+ /// must refuse to authorize a key that has an unrecognised option.
///
public IDictionary CriticalOptions
{
diff --git a/src/Renci.SshNet/Security/Cryptography/Ciphers/AesGcmCipher.cs b/src/Renci.SshNet/Security/Cryptography/Ciphers/AesGcmCipher.cs
index 820416bb..ded36fc0 100644
--- a/src/Renci.SshNet/Security/Cryptography/Ciphers/AesGcmCipher.cs
+++ b/src/Renci.SshNet/Security/Cryptography/Ciphers/AesGcmCipher.cs
@@ -22,7 +22,7 @@ namespace Renci.SshNet.Security.Cryptography.Ciphers
#endif
///
- /// Gets the minimun block size.
+ /// Gets the minimum block size.
/// The reader is reminded that SSH requires that the data to be
/// encrypted MUST be padded out to a multiple of the block size
/// (16-octets for AES-GCM).
@@ -164,7 +164,7 @@ namespace Renci.SshNet.Security.Cryptography.Ciphers
///
/// Dispose the instance.
///
- /// Set to True to dispose of resouces.
+ /// Set to True to dispose of resources.
public void Dispose(bool disposing)
{
if (disposing)
diff --git a/src/Renci.SshNet/Security/Cryptography/Ciphers/ChaCha20Poly1305Cipher.cs b/src/Renci.SshNet/Security/Cryptography/Ciphers/ChaCha20Poly1305Cipher.cs
index 5f63660c..1559c263 100644
--- a/src/Renci.SshNet/Security/Cryptography/Ciphers/ChaCha20Poly1305Cipher.cs
+++ b/src/Renci.SshNet/Security/Cryptography/Ciphers/ChaCha20Poly1305Cipher.cs
@@ -27,7 +27,7 @@ namespace Renci.SshNet.Security.Cryptography.Ciphers
private readonly Poly1305 _mac;
///
- /// Gets the minimun block size.
+ /// Gets the minimum block size.
///
public override byte MinimumSize
{
diff --git a/src/Renci.SshNet/Security/SshKeyData.cs b/src/Renci.SshNet/Security/SshKeyData.cs
index 0a1467a5..f57143fd 100644
--- a/src/Renci.SshNet/Security/SshKeyData.cs
+++ b/src/Renci.SshNet/Security/SshKeyData.cs
@@ -58,7 +58,7 @@ namespace Renci.SshNet.Security
///
/// Initializes a new instance of the class.
///
- /// The public key format identifer.
+ /// The public key format identifier.
/// The public key constituents.
public SshKeyData(string name, BigInteger[] keys)
{
diff --git a/src/Renci.SshNet/Session.cs b/src/Renci.SshNet/Session.cs
index dc252c39..64fc12b0 100644
--- a/src/Renci.SshNet/Session.cs
+++ b/src/Renci.SshNet/Session.cs
@@ -355,6 +355,7 @@ namespace Renci.SshNet
///
/// Occurs when an error occurred.
///
+ /// A known misspelling of "occurred" preserved for backward compatibility.
public event EventHandler ErrorOccured;
///
diff --git a/src/Renci.SshNet/SftpClient.cs b/src/Renci.SshNet/SftpClient.cs
index e6d4efc1..1869bcaa 100644
--- a/src/Renci.SshNet/SftpClient.cs
+++ b/src/Renci.SshNet/SftpClient.cs
@@ -2165,7 +2165,7 @@ namespace Renci.SshNet
ThrowHelper.ThrowIfNull(sourcePath);
ThrowHelper.ThrowIfNullOrWhiteSpace(destinationPath);
- return InternalSynchronizeDirectories(sourcePath, destinationPath, searchPattern, asynchResult: null);
+ return InternalSynchronizeDirectories(sourcePath, destinationPath, searchPattern, asyncResult: null);
}
///
@@ -2227,7 +2227,7 @@ namespace Renci.SshNet
return ar.EndInvoke();
}
- private List InternalSynchronizeDirectories(string sourcePath, string destinationPath, string searchPattern, SftpSynchronizeDirectoriesAsyncResult? asynchResult)
+ private List InternalSynchronizeDirectories(string sourcePath, string destinationPath, string searchPattern, SftpSynchronizeDirectoriesAsyncResult? asyncResult)
{
if (!Directory.Exists(sourcePath))
{
@@ -2293,7 +2293,7 @@ namespace Renci.SshNet
uploadedFiles.Add(localFile);
- asynchResult?.Update(uploadedFiles.Count);
+ asyncResult?.Update(uploadedFiles.Count);
}
catch (Exception ex)
{
@@ -2318,7 +2318,7 @@ namespace Renci.SshNet
/// An that references the asynchronous request.
/// The list callback.
///
- /// A list of files in the specfied directory.
+ /// A list of files in the specified directory.
///
/// is .
/// Client not connected.
@@ -2490,7 +2490,7 @@ namespace Renci.SshNet
// We will send out all the write requests without waiting for each response.
// Afterwards, we may wait on this handle until all responses are received
- // or an error has occured.
+ // or an error has occurred.
using var mres = new ManualResetEventSlim(initialState: false);
ExceptionDispatchInfo? exception = null;
diff --git a/src/Renci.SshNet/Shell.cs b/src/Renci.SshNet/Shell.cs
index 909d8f50..54c22987 100644
--- a/src/Renci.SshNet/Shell.cs
+++ b/src/Renci.SshNet/Shell.cs
@@ -154,7 +154,7 @@ namespace Renci.SshNet
_channel.ExtendedDataReceived += Channel_ExtendedDataReceived;
_channel.Closed += Channel_Closed;
_session.Disconnected += Session_Disconnected;
- _session.ErrorOccured += Session_ErrorOccured;
+ _session.ErrorOccured += Session_ErrorOccurred;
_channel.Open();
if (!_noTerminal)
@@ -224,7 +224,7 @@ namespace Renci.SshNet
_channel?.Dispose();
}
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
RaiseError(e);
}
@@ -297,7 +297,7 @@ namespace Renci.SshNet
}
session.Disconnected -= Session_Disconnected;
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
}
private bool _disposed;
diff --git a/src/Renci.SshNet/ShellStream.cs b/src/Renci.SshNet/ShellStream.cs
index f7dc862a..1bd58c5c 100644
--- a/src/Renci.SshNet/ShellStream.cs
+++ b/src/Renci.SshNet/ShellStream.cs
@@ -162,7 +162,7 @@ namespace Renci.SshNet
_channel.DataReceived += Channel_DataReceived;
_channel.Closed += Channel_Closed;
_session.Disconnected += Session_Disconnected;
- _session.ErrorOccured += Session_ErrorOccured;
+ _session.ErrorOccured += Session_ErrorOccurred;
_readBuffer = new System.Net.ArrayBuffer(bufferSize);
_writeBuffer = new System.Net.ArrayBuffer(bufferSize);
@@ -927,7 +927,7 @@ namespace Renci.SshNet
// Do not dispose _session (we don't own it)
_session.Disconnected -= Session_Disconnected;
- _session.ErrorOccured -= Session_ErrorOccured;
+ _session.ErrorOccured -= Session_ErrorOccurred;
// But we do own _channel
_channel.DataReceived -= Channel_DataReceived;
@@ -940,7 +940,7 @@ namespace Renci.SshNet
base.Dispose(disposing);
}
- private void Session_ErrorOccured(object? sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object? sender, ExceptionEventArgs e)
{
ErrorOccurred?.Invoke(this, e);
}
diff --git a/src/Renci.SshNet/SshCommand.cs b/src/Renci.SshNet/SshCommand.cs
index 1a3c6945..d329ba4d 100644
--- a/src/Renci.SshNet/SshCommand.cs
+++ b/src/Renci.SshNet/SshCommand.cs
@@ -225,7 +225,7 @@ namespace Renci.SshNet
OutputStream = new PipeStream();
ExtendedOutputStream = new PipeStream();
_session.Disconnected += Session_Disconnected;
- _session.ErrorOccured += Session_ErrorOccured;
+ _session.ErrorOccured += Session_ErrorOccurred;
_channel = _session.CreateChannelSession();
}
@@ -263,7 +263,7 @@ namespace Renci.SshNet
OutputStream.Dispose();
ExtendedOutputStream.Dispose();
- // Initialize output streams. We already initialised them for the first
+ // Initialise output streams. We already initialised them for the first
// execution in the constructor (to allow passing them around before execution)
// so we just need to reinitialise them for subsequent executions.
OutputStream = new PipeStream();
@@ -512,7 +512,7 @@ namespace Renci.SshNet
SetAsyncComplete(setResult: false);
}
- private void Session_ErrorOccured(object? sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object? sender, ExceptionEventArgs e)
{
_ = _tcs?.TrySetException(e.Exception);
@@ -642,7 +642,7 @@ namespace Renci.SshNet
// unsubscribe from session events to ensure other objects that we're going to dispose
// are not accessed while disposing
_session.Disconnected -= Session_Disconnected;
- _session.ErrorOccured -= Session_ErrorOccured;
+ _session.ErrorOccured -= Session_ErrorOccurred;
// unsubscribe from channel events to ensure other objects that we're going to dispose
// are not accessed while disposing
diff --git a/src/Renci.SshNet/SubsystemSession.cs b/src/Renci.SshNet/SubsystemSession.cs
index 6c6200f4..af304467 100644
--- a/src/Renci.SshNet/SubsystemSession.cs
+++ b/src/Renci.SshNet/SubsystemSession.cs
@@ -27,7 +27,7 @@ namespace Renci.SshNet
private ISession _session;
private IChannelSession _channel;
private Exception _exception;
- private EventWaitHandle _errorOccuredWaitHandle = new ManualResetEvent(initialState: false);
+ private EventWaitHandle _errorOccurredWaitHandle = new ManualResetEvent(initialState: false);
private EventWaitHandle _sessionDisconnectedWaitHandle = new ManualResetEvent(initialState: false);
private EventWaitHandle _channelClosedWaitHandle = new ManualResetEvent(initialState: false);
private bool _isDisposed;
@@ -106,12 +106,12 @@ namespace Renci.SshNet
}
// reset waithandles in case we're reconnecting
- _ = _errorOccuredWaitHandle.Reset();
+ _ = _errorOccurredWaitHandle.Reset();
_ = _sessionDisconnectedWaitHandle.Reset();
_ = _sessionDisconnectedWaitHandle.Reset();
_ = _channelClosedWaitHandle.Reset();
- _session.ErrorOccured += Session_ErrorOccured;
+ _session.ErrorOccured += Session_ErrorOccurred;
_session.Disconnected += Session_Disconnected;
_channel = _session.CreateChannelSession();
@@ -185,7 +185,7 @@ namespace Renci.SshNet
_logger.LogInformation(error, "Raised exception");
- _ = _errorOccuredWaitHandle?.Set();
+ _ = _errorOccurredWaitHandle?.Set();
SignalErrorOccurred(error);
}
@@ -224,7 +224,7 @@ namespace Renci.SshNet
{
var waitHandles = new[]
{
- _errorOccuredWaitHandle,
+ _errorOccurredWaitHandle,
_sessionDisconnectedWaitHandle,
_channelClosedWaitHandle,
waitHandle
@@ -253,8 +253,8 @@ namespace Renci.SshNet
{
cancellationToken.ThrowIfCancellationRequested();
- var errorOccuredReg = ThreadPool.RegisterWaitForSingleObject(
- _errorOccuredWaitHandle,
+ var errorOccurredReg = ThreadPool.RegisterWaitForSingleObject(
+ _errorOccurredWaitHandle,
(tcs, _) => ((TaskCompletionSource)tcs).TrySetException(_exception),
state: tcs,
millisecondsTimeOutInterval: -1,
@@ -296,7 +296,7 @@ namespace Renci.SshNet
}
finally
{
- _ = errorOccuredReg.Unregister(waitObject: null);
+ _ = errorOccurredReg.Unregister(waitObject: null);
_ = sessionDisconnectedReg.Unregister(waitObject: null);
_ = channelClosedReg.Unregister(waitObject: null);
}
@@ -323,7 +323,7 @@ namespace Renci.SshNet
{
var waitHandles = new[]
{
- _errorOccuredWaitHandle,
+ _errorOccurredWaitHandle,
_sessionDisconnectedWaitHandle,
_channelClosedWaitHandle,
waitHandle
@@ -377,7 +377,7 @@ namespace Renci.SshNet
{
var waitHandles = new[]
{
- _errorOccuredWaitHandle,
+ _errorOccurredWaitHandle,
_sessionDisconnectedWaitHandle,
_channelClosedWaitHandle,
waitHandleA,
@@ -416,7 +416,7 @@ namespace Renci.SshNet
///
/// The connection was closed by the server.
/// The channel was closed.
- /// No object satified the wait and a time interval equivalent to has passed.
+ /// No object satisfied the wait and a time interval equivalent to has passed.
///
/// For the return value, the index of the first non-system object is considered to be zero.
///
@@ -452,7 +452,7 @@ namespace Renci.SshNet
{
return new WaitHandle[]
{
- _errorOccuredWaitHandle,
+ _errorOccurredWaitHandle,
_sessionDisconnectedWaitHandle,
_channelClosedWaitHandle,
waitHandle1,
@@ -471,7 +471,7 @@ namespace Renci.SshNet
public WaitHandle[] CreateWaitHandleArray(params WaitHandle[] waitHandles)
{
var array = new WaitHandle[waitHandles.Length + SystemWaitHandleCount];
- array[0] = _errorOccuredWaitHandle;
+ array[0] = _errorOccurredWaitHandle;
array[1] = _sessionDisconnectedWaitHandle;
array[2] = _channelClosedWaitHandle;
@@ -490,7 +490,7 @@ namespace Renci.SshNet
SignalDisconnected();
}
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
RaiseError(e.Exception);
}
@@ -528,7 +528,7 @@ namespace Renci.SshNet
}
session.Disconnected -= Session_Disconnected;
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
}
///
@@ -557,11 +557,11 @@ namespace Renci.SshNet
_session = null;
- var errorOccuredWaitHandle = _errorOccuredWaitHandle;
- if (errorOccuredWaitHandle != null)
+ var errorOccurredWaitHandle = _errorOccurredWaitHandle;
+ if (errorOccurredWaitHandle != null)
{
- _errorOccuredWaitHandle = null;
- errorOccuredWaitHandle.Dispose();
+ _errorOccurredWaitHandle = null;
+ errorOccurredWaitHandle.Dispose();
}
var sessionDisconnectedWaitHandle = _sessionDisconnectedWaitHandle;
diff --git a/src/exclusion.dic b/src/exclusion.dic
new file mode 100644
index 00000000..186ea9d5
--- /dev/null
+++ b/src/exclusion.dic
@@ -0,0 +1,2 @@
+renci
+openssh
diff --git a/test/.editorconfig b/test/.editorconfig
index e0a4a8b8..5cc9439f 100644
--- a/test/.editorconfig
+++ b/test/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Sonar rules ####
diff --git a/test/Renci.SshNet.Benchmarks/.editorconfig b/test/Renci.SshNet.Benchmarks/.editorconfig
index 29255dc3..d11bbc54 100644
--- a/test/Renci.SshNet.Benchmarks/.editorconfig
+++ b/test/Renci.SshNet.Benchmarks/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Sonar rules ####
diff --git a/test/Renci.SshNet.IntegrationBenchmarks/.editorconfig b/test/Renci.SshNet.IntegrationBenchmarks/.editorconfig
index 3e3e6d5e..2b196929 100644
--- a/test/Renci.SshNet.IntegrationBenchmarks/.editorconfig
+++ b/test/Renci.SshNet.IntegrationBenchmarks/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Sonar rules ####
diff --git a/test/Renci.SshNet.IntegrationTests/.editorconfig b/test/Renci.SshNet.IntegrationTests/.editorconfig
index ecfbce76..6168c7bb 100644
--- a/test/Renci.SshNet.IntegrationTests/.editorconfig
+++ b/test/Renci.SshNet.IntegrationTests/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Sonar rules ####
diff --git a/test/Renci.SshNet.IntegrationTests/ScpTests.cs b/test/Renci.SshNet.IntegrationTests/ScpTests.cs
index 5a131865..d12d08f0 100644
--- a/test/Renci.SshNet.IntegrationTests/ScpTests.cs
+++ b/test/Renci.SshNet.IntegrationTests/ScpTests.cs
@@ -1596,11 +1596,11 @@ namespace Renci.SshNet.IntegrationTests
var remotePathFile1 = CombinePaths(remoteDirectory, "file1");
var remotePathFile2 = CombinePaths(remoteDirectory, "file2");
- var absoluteremoteSubDirectory1 = CombinePaths(absoluteRemoteDirectory, "sub1");
+ var absoluteRemoteSubDirectory1 = CombinePaths(absoluteRemoteDirectory, "sub1");
var remoteSubDirectory1 = CombinePaths(remoteDirectory, "sub1");
var remotePathSubFile1 = CombinePaths(remoteSubDirectory1, "file1");
var remotePathSubFile2 = CombinePaths(remoteSubDirectory1, "file2");
- var absoluteremoteSubDirectory2 = CombinePaths(absoluteRemoteDirectory, "sub2");
+ var absoluteRemoteSubDirectory2 = CombinePaths(absoluteRemoteDirectory, "sub2");
var remoteSubDirectory2 = CombinePaths(remoteDirectory, "sub2");
using (var client = new SftpClient(_connectionInfoFactory.Create()))
@@ -1726,7 +1726,7 @@ namespace Renci.SshNet.IntegrationTests
Assert.IsTrue(client.Exists(remoteSubDirectory1));
remoteSftpDirectory = client.Get(remoteSubDirectory1);
Assert.IsNotNull(remoteSftpDirectory);
- Assert.AreEqual(absoluteremoteSubDirectory1, remoteSftpDirectory.FullName);
+ Assert.AreEqual(absoluteRemoteSubDirectory1, remoteSftpDirectory.FullName);
Assert.IsTrue(remoteSftpDirectory.IsDirectory);
Assert.IsFalse(remoteSftpDirectory.IsRegularFile);
Assert.AreEqual(Directory.GetLastWriteTimeUtc(localSubDirectory1), remoteSftpDirectory.LastWriteTimeUtc);
@@ -1740,7 +1740,7 @@ namespace Renci.SshNet.IntegrationTests
Assert.IsTrue(client.Exists(remoteSubDirectory2));
remoteSftpDirectory = client.Get(remoteSubDirectory2);
Assert.IsNotNull(remoteSftpDirectory);
- Assert.AreEqual(absoluteremoteSubDirectory2, remoteSftpDirectory.FullName);
+ Assert.AreEqual(absoluteRemoteSubDirectory2, remoteSftpDirectory.FullName);
Assert.IsTrue(remoteSftpDirectory.IsDirectory);
Assert.IsFalse(remoteSftpDirectory.IsRegularFile);
Assert.AreEqual(Directory.GetLastWriteTimeUtc(localSubDirectory2), remoteSftpDirectory.LastWriteTimeUtc);
diff --git a/test/Renci.SshNet.IntegrationTests/SftpTests.cs b/test/Renci.SshNet.IntegrationTests/SftpTests.cs
index 83275e0e..64ca1521 100644
--- a/test/Renci.SshNet.IntegrationTests/SftpTests.cs
+++ b/test/Renci.SshNet.IntegrationTests/SftpTests.cs
@@ -4570,9 +4570,9 @@ namespace Renci.SshNet.IntegrationTests
Assert.AreEqual(seekOffset + writeBuffer.Length, fs.Length);
Assert.AreEqual(0x04, fs.ReadByte());
- var soughtOverReadBufferffer = new byte[seekOffset - 1];
- Assert.AreEqual(soughtOverReadBufferffer.Length, fs.Read(soughtOverReadBufferffer, offset: 0, soughtOverReadBufferffer.Length));
- Assert.IsTrue(new byte[soughtOverReadBufferffer.Length].IsEqualTo(soughtOverReadBufferffer));
+ var soughtOverReadBuffer = new byte[seekOffset - 1];
+ Assert.AreEqual(soughtOverReadBuffer.Length, fs.Read(soughtOverReadBuffer, offset: 0, soughtOverReadBuffer.Length));
+ Assert.IsTrue(new byte[soughtOverReadBuffer.Length].IsEqualTo(soughtOverReadBuffer));
var readBuffer = new byte[writeBuffer.Length];
Assert.AreEqual(readBuffer.Length, fs.Read(readBuffer, offset: 0, readBuffer.Length));
@@ -4612,9 +4612,9 @@ namespace Renci.SshNet.IntegrationTests
Assert.AreEqual(seekOffset + writeBuffer.Length, fs.Length);
Assert.AreEqual(0x04, fs.ReadByte());
- var soughtOverReadBufferffer = new byte[seekOffset - 1];
- Assert.AreEqual(soughtOverReadBufferffer.Length, fs.Read(soughtOverReadBufferffer, offset: 0, soughtOverReadBufferffer.Length));
- Assert.IsTrue(new byte[soughtOverReadBufferffer.Length].IsEqualTo(soughtOverReadBufferffer));
+ var soughtOverReadBuffer = new byte[seekOffset - 1];
+ Assert.AreEqual(soughtOverReadBuffer.Length, fs.Read(soughtOverReadBuffer, offset: 0, soughtOverReadBuffer.Length));
+ Assert.IsTrue(new byte[soughtOverReadBuffer.Length].IsEqualTo(soughtOverReadBuffer));
var readBuffer = new byte[writeBuffer.Length];
Assert.AreEqual(readBuffer.Length, fs.Read(readBuffer, offset: 0, readBuffer.Length));
@@ -5315,9 +5315,9 @@ namespace Renci.SshNet.IntegrationTests
Assert.AreEqual(seekOffset + writeBuffer.Length, fs.Length);
Assert.AreEqual(0x04, fs.ReadByte());
- var soughtOverReadBufferffer = new byte[seekOffset - 1];
- Assert.AreEqual(soughtOverReadBufferffer.Length, fs.Read(soughtOverReadBufferffer, offset: 0, soughtOverReadBufferffer.Length));
- Assert.IsTrue(new byte[soughtOverReadBufferffer.Length].IsEqualTo(soughtOverReadBufferffer));
+ var soughtOverReadBuffer = new byte[seekOffset - 1];
+ Assert.AreEqual(soughtOverReadBuffer.Length, fs.Read(soughtOverReadBuffer, offset: 0, soughtOverReadBuffer.Length));
+ Assert.IsTrue(new byte[soughtOverReadBuffer.Length].IsEqualTo(soughtOverReadBuffer));
var readBuffer = new byte[writeBuffer.Length];
Assert.AreEqual(readBuffer.Length, fs.Read(readBuffer, offset: 0, readBuffer.Length));
@@ -5398,9 +5398,9 @@ namespace Renci.SshNet.IntegrationTests
Assert.AreEqual(0x04, fs.ReadByte());
- var soughtOverReadBufferffer = new byte[seekOffset - 1];
- Assert.AreEqual(seekOffset - 1, fs.Read(soughtOverReadBufferffer, offset: 0, soughtOverReadBufferffer.Length));
- Assert.IsTrue(new byte[seekOffset - 1].IsEqualTo(soughtOverReadBufferffer));
+ var soughtOverReadBuffer = new byte[seekOffset - 1];
+ Assert.AreEqual(seekOffset - 1, fs.Read(soughtOverReadBuffer, offset: 0, soughtOverReadBuffer.Length));
+ Assert.IsTrue(new byte[seekOffset - 1].IsEqualTo(soughtOverReadBuffer));
var readBuffer = new byte[writeBuffer.Length];
Assert.AreEqual(writeBuffer.Length, fs.Read(readBuffer, offset: 0, readBuffer.Length));
diff --git a/test/Renci.SshNet.IntegrationTests/SshTests.cs b/test/Renci.SshNet.IntegrationTests/SshTests.cs
index ba84365b..276030e5 100644
--- a/test/Renci.SshNet.IntegrationTests/SshTests.cs
+++ b/test/Renci.SshNet.IntegrationTests/SshTests.cs
@@ -831,7 +831,7 @@ namespace Renci.SshNet.IntegrationTests
continue;
}
- // If hostname is currently mapped to another IP address, then remove the
+ // If hostname is currently mapped to another IP address, then remove the
// current mapping
hostConfig.Entries.RemoveAt(i);
}
diff --git a/test/Renci.SshNet.TestTools.OpenSSH/.editorconfig b/test/Renci.SshNet.TestTools.OpenSSH/.editorconfig
index f09ad633..fd466cf2 100644
--- a/test/Renci.SshNet.TestTools.OpenSSH/.editorconfig
+++ b/test/Renci.SshNet.TestTools.OpenSSH/.editorconfig
@@ -1,4 +1,6 @@
[*.cs]
+spelling_exclusion_path = ../../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Meziantou.Analyzer rules ####
diff --git a/test/Renci.SshNet.Tests/.editorconfig b/test/Renci.SshNet.Tests/.editorconfig
index e3ef92c0..e8401b72 100644
--- a/test/Renci.SshNet.Tests/.editorconfig
+++ b/test/Renci.SshNet.Tests/.editorconfig
@@ -1,4 +1,7 @@
[*.cs]
+spelling_languages = en-us,en-gb
+spelling_exclusion_path = ../../exclusion.dic
+spelling_checkable_types = identifiers,comments
#### Sonar rules ####
diff --git a/test/Renci.SshNet.Tests/Classes/BaseClientTest_Connect_OnConnectedThrowsException.cs b/test/Renci.SshNet.Tests/Classes/BaseClientTest_Connect_OnConnectedThrowsException.cs
index caeb7f23..b49eac8d 100644
--- a/test/Renci.SshNet.Tests/Classes/BaseClientTest_Connect_OnConnectedThrowsException.cs
+++ b/test/Renci.SshNet.Tests/Classes/BaseClientTest_Connect_OnConnectedThrowsException.cs
@@ -102,7 +102,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void ErrorOccuredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnBaseClient()
+ public void ErrorOccurredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnBaseClient()
{
var errorOccurredSignalCount = 0;
diff --git a/test/Renci.SshNet.Tests/Classes/BaseClientTest_Disconnected_Connect.cs b/test/Renci.SshNet.Tests/Classes/BaseClientTest_Disconnected_Connect.cs
index db2cac1c..79665089 100644
--- a/test/Renci.SshNet.Tests/Classes/BaseClientTest_Disconnected_Connect.cs
+++ b/test/Renci.SshNet.Tests/Classes/BaseClientTest_Disconnected_Connect.cs
@@ -78,7 +78,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void CreateSocketFactoryOnServiceFactoryShouldBeInvokedTwic()
+ public void CreateSocketFactoryOnServiceFactoryShouldBeInvokedTwice()
{
ServiceFactoryMock.Verify(p => p.CreateSocketFactory(), Times.Exactly(2));
}
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelDirectTcpipTest.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelDirectTcpipTest.cs
index 0b67b917..ab15e7e2 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelDirectTcpipTest.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelDirectTcpipTest.cs
@@ -142,7 +142,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
{
// sleep for a short period to allow channel to actually start receiving from socket
Thread.Sleep(100);
- // raise ErrorOccured event on session
+ // raise ErrorOccurred event on session
_sessionMock.Raise(s => s.ErrorOccured += null,
new ExceptionEventArgs(new SystemException()));
});
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvalable.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvailable.cs
similarity index 99%
rename from test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvalable.cs
rename to test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvailable.cs
index 2ecc4092..78ffa1ec 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvalable.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvailable.cs
@@ -14,7 +14,7 @@ using Renci.SshNet.Messages.Connection;
namespace Renci.SshNet.Tests.Classes.Channels
{
[TestClass]
- public class ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvalable : ChannelSessionTestBase
+ public class ChannelSessionTest_Open_OnOpenFailureReceived_RetriesAvailable : ChannelSessionTestBase
{
private ChannelSession _channel;
private uint _localChannelNumber;
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelStub.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelStub.cs
index 119c3d58..9ce0d2b1 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelStub.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelStub.cs
@@ -108,7 +108,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
}
- protected override void OnErrorOccured(Exception exp)
+ protected override void OnErrorOccurred(Exception exp)
{
OnErrorOccurredInvocations.Add(exp);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelCloseReceived_OnClose_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelCloseReceived_OnClose_Exception.cs
index af4936e1..964ae98b 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelCloseReceived_OnClose_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelCloseReceived_OnClose_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onCloseException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelDataReceived_OnData_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelDataReceived_OnData_Exception.cs
index 0703ca60..6ad785d8 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelDataReceived_OnData_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelDataReceived_OnData_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onDataException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelEofReceived_OnEof_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelEofReceived_OnEof_Exception.cs
index a97031bf..c4f7f433 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelEofReceived_OnEof_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelEofReceived_OnEof_Exception.cs
@@ -64,7 +64,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onEofException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelExtendedDataReceived_OnExtendedData_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelExtendedDataReceived_OnExtendedData_Exception.cs
index f07e0198..84892795 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelExtendedDataReceived_OnExtendedData_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelExtendedDataReceived_OnExtendedData_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onExtendedDataException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelFailureReceived_OnFailure_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelFailureReceived_OnFailure_Exception.cs
index 3709b2de..b0b3d813 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelFailureReceived_OnFailure_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelFailureReceived_OnFailure_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onFailureException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelRequestReceived_OnRequest_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelRequestReceived_OnRequest_Exception.cs
index 62fe98ad..860fc684 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelRequestReceived_OnRequest_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelRequestReceived_OnRequest_Exception.cs
@@ -60,7 +60,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onRequestException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelSuccessReceived_OnSuccess_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelSuccessReceived_OnSuccess_Exception.cs
index b49b0b7b..a1275306 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelSuccessReceived_OnSuccess_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelSuccessReceived_OnSuccess_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onSuccessException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelWindowAdjustReceived_OnWindowAdjust_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelWindowAdjustReceived_OnWindowAdjust_Exception.cs
index afad6eb8..5f0686ef 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelWindowAdjustReceived_OnWindowAdjust_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionChannelWindowAdjustReceived_OnWindowAdjust_Exception.cs
@@ -65,7 +65,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onWindowAdjustException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionDisconnected_OnDisconnected_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionDisconnected_OnDisconnected_Exception.cs
index 693adbd7..6900ac72 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionDisconnected_OnDisconnected_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionDisconnected_OnDisconnected_Exception.cs
@@ -54,7 +54,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onDisconnectedException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionErrorOccurred_OnErrorOccurred_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionErrorOccurred_OnErrorOccurred_Exception.cs
index 1dd45bbe..eabb0eab 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionErrorOccurred_OnErrorOccurred_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ChannelTest_OnSessionErrorOccurred_OnErrorOccurred_Exception.cs
@@ -56,7 +56,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_errorOccurredException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelStub.cs b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelStub.cs
index 07ac5dad..fffb3afb 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelStub.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelStub.cs
@@ -112,7 +112,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
}
- protected override void OnErrorOccured(Exception exp)
+ protected override void OnErrorOccurred(Exception exp)
{
OnErrorOccurredInvocations.Add(exp);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenConfirmationReceived_OnOpenConfirmation_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenConfirmationReceived_OnOpenConfirmation_Exception.cs
index 9fcdc6d4..0f0ec607 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenConfirmationReceived_OnOpenConfirmation_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenConfirmationReceived_OnOpenConfirmation_Exception.cs
@@ -62,7 +62,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onOpenConfirmationException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenFailureReceived_OnOpenFailure_Exception.cs b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenFailureReceived_OnOpenFailure_Exception.cs
index ad2b6ad1..1a76ef5a 100644
--- a/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenFailureReceived_OnOpenFailure_Exception.cs
+++ b/test/Renci.SshNet.Tests/Classes/Channels/ClientChannelTest_OnSessionChannelOpenFailureReceived_OnOpenFailure_Exception.cs
@@ -59,7 +59,7 @@ namespace Renci.SshNet.Tests.Classes.Channels
}
[TestMethod]
- public void OnErrorOccuredShouldBeInvokedOnce()
+ public void OnErrorOccurredShouldBeInvokedOnce()
{
Assert.AreEqual(1, _channel.OnErrorOccurredInvocations.Count);
Assert.AreSame(_onOpenFailureException, _channel.OnErrorOccurredInvocations[0]);
diff --git a/test/Renci.SshNet.Tests/Classes/ConnectionInfoTest.cs b/test/Renci.SshNet.Tests/Classes/ConnectionInfoTest.cs
index 4e143bbc..407eb5a3 100644
--- a/test/Renci.SshNet.Tests/Classes/ConnectionInfoTest.cs
+++ b/test/Renci.SshNet.Tests/Classes/ConnectionInfoTest.cs
@@ -19,7 +19,7 @@ namespace Renci.SshNet.Tests.Classes
{
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldNotThrowExceptionhenProxyTypesIsNoneAndProxyHostIsNull()
+ public void ConstructorShouldNotThrowExceptionWhenProxyTypesIsNoneAndProxyHostIsNull()
{
const string proxyHost = null;
@@ -32,7 +32,7 @@ namespace Renci.SshNet.Tests.Classes
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldThrowArgumentNullExceptionhenProxyTypesIsNotNoneAndProxyHostIsNull()
+ public void ConstructorShouldThrowArgumentNullExceptionWhenProxyTypesIsNotNoneAndProxyHostIsNull()
{
try
{
@@ -153,7 +153,7 @@ namespace Renci.SshNet.Tests.Classes
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldThrowArgumentNullExceptionhenHostIsNull()
+ public void ConstructorShouldThrowArgumentNullExceptionWhenHostIsNull()
{
try
{
@@ -358,7 +358,7 @@ namespace Renci.SshNet.Tests.Classes
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldThrowArgumentExceptionhenUsernameIsNull()
+ public void ConstructorShouldThrowArgumentExceptionWhenUsernameIsNull()
{
const string username = null;
@@ -384,7 +384,7 @@ namespace Renci.SshNet.Tests.Classes
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldThrowArgumentExceptionhenUsernameIsEmpty()
+ public void ConstructorShouldThrowArgumentExceptionWhenUsernameIsEmpty()
{
var username = string.Empty;
@@ -411,7 +411,7 @@ namespace Renci.SshNet.Tests.Classes
[TestMethod]
[TestCategory("ConnectionInfo")]
- public void ConstructorShouldThrowArgumentExceptionhenUsernameContainsOnlyWhitespace()
+ public void ConstructorShouldThrowArgumentExceptionWhenUsernameContainsOnlyWhitespace()
{
const string username = " \t\r";
diff --git a/test/Renci.SshNet.Tests/Classes/ForwardedPortDynamicTest_Start_PortStarted.cs b/test/Renci.SshNet.Tests/Classes/ForwardedPortDynamicTest_Start_PortStarted.cs
index 0124a8db..e7c11548 100644
--- a/test/Renci.SshNet.Tests/Classes/ForwardedPortDynamicTest_Start_PortStarted.cs
+++ b/test/Renci.SshNet.Tests/Classes/ForwardedPortDynamicTest_Start_PortStarted.cs
@@ -77,7 +77,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void StartShouldThrowInvalidOperatationException()
+ public void StartShouldThrowInvalidOperationException()
{
Assert.IsNotNull(_actualException);
Assert.AreEqual("Forwarded port is already started.", _actualException.Message);
diff --git a/test/Renci.SshNet.Tests/Classes/ForwardedPortLocalTest_Start_PortStarted.cs b/test/Renci.SshNet.Tests/Classes/ForwardedPortLocalTest_Start_PortStarted.cs
index e9e07e39..1af1f7e6 100644
--- a/test/Renci.SshNet.Tests/Classes/ForwardedPortLocalTest_Start_PortStarted.cs
+++ b/test/Renci.SshNet.Tests/Classes/ForwardedPortLocalTest_Start_PortStarted.cs
@@ -83,7 +83,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void StartShouldThrowInvalidOperatationException()
+ public void StartShouldThrowInvalidOperationException()
{
Assert.IsNotNull(_actualException);
Assert.AreEqual("Forwarded port is already started.", _actualException.Message);
diff --git a/test/Renci.SshNet.Tests/Classes/ForwardedPortRemoteTest_Start_PortStarted.cs b/test/Renci.SshNet.Tests/Classes/ForwardedPortRemoteTest_Start_PortStarted.cs
index c6cf0850..6c5c0cc6 100644
--- a/test/Renci.SshNet.Tests/Classes/ForwardedPortRemoteTest_Start_PortStarted.cs
+++ b/test/Renci.SshNet.Tests/Classes/ForwardedPortRemoteTest_Start_PortStarted.cs
@@ -103,7 +103,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void StartShouldThrowInvalidOperatationException()
+ public void StartShouldThrowInvalidOperationException()
{
Assert.IsNotNull(_actualException);
Assert.AreEqual("Forwarded port is already started.", _actualException.Message);
diff --git a/test/Renci.SshNet.Tests/Classes/ForwardedPortStatusTest_Stopped.cs b/test/Renci.SshNet.Tests/Classes/ForwardedPortStatusTest_Stopped.cs
index a3836aa0..aae846b6 100644
--- a/test/Renci.SshNet.Tests/Classes/ForwardedPortStatusTest_Stopped.cs
+++ b/test/Renci.SshNet.Tests/Classes/ForwardedPortStatusTest_Stopped.cs
@@ -49,7 +49,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void Equals_ShouldReturTrueWhenOtherIsStopped()
+ public void Equals_ShouldReturnTrueWhenOtherIsStopped()
{
var other = ForwardedPortStatus.Stopped;
diff --git a/test/Renci.SshNet.Tests/Classes/NetConfClientTest_Connect_NetConfSessionConnectFailure.cs b/test/Renci.SshNet.Tests/Classes/NetConfClientTest_Connect_NetConfSessionConnectFailure.cs
index 1585d873..a5b7e03a 100644
--- a/test/Renci.SshNet.Tests/Classes/NetConfClientTest_Connect_NetConfSessionConnectFailure.cs
+++ b/test/Renci.SshNet.Tests/Classes/NetConfClientTest_Connect_NetConfSessionConnectFailure.cs
@@ -84,7 +84,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void ErrorOccuredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnNetConfClient()
+ public void ErrorOccurredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnNetConfClient()
{
var errorOccurredSignalCount = 0;
diff --git a/test/Renci.SshNet.Tests/Classes/SftpClientTest_Connect_SftpSessionConnectFailure.cs b/test/Renci.SshNet.Tests/Classes/SftpClientTest_Connect_SftpSessionConnectFailure.cs
index 1b2a068c..2f52a51c 100644
--- a/test/Renci.SshNet.Tests/Classes/SftpClientTest_Connect_SftpSessionConnectFailure.cs
+++ b/test/Renci.SshNet.Tests/Classes/SftpClientTest_Connect_SftpSessionConnectFailure.cs
@@ -93,7 +93,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void ErrorOccuredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnSftpClient()
+ public void ErrorOccurredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnSftpClient()
{
var errorOccurredSignalCount = 0;
diff --git a/test/Renci.SshNet.Tests/Classes/ShellStreamTest_Write_WriteBufferEmptyAndWriteMoreBytesThanBufferSize.cs b/test/Renci.SshNet.Tests/Classes/ShellStreamTest_Write_WriteBufferEmptyAndWriteMoreBytesThanBufferSize.cs
index d52e55c0..997863cf 100644
--- a/test/Renci.SshNet.Tests/Classes/ShellStreamTest_Write_WriteBufferEmptyAndWriteMoreBytesThanBufferSize.cs
+++ b/test/Renci.SshNet.Tests/Classes/ShellStreamTest_Write_WriteBufferEmptyAndWriteMoreBytesThanBufferSize.cs
@@ -129,7 +129,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void FlushShouldSendRemaningBytesToServer()
+ public void FlushShouldSendRemainingBytesToServer()
{
var expectedBytesSent = _data.Take(_bufferSize * 2, _data.Length - (_bufferSize * 2));
diff --git a/test/Renci.SshNet.Tests/Classes/SshCommandTest_Dispose.cs b/test/Renci.SshNet.Tests/Classes/SshCommandTest_Dispose.cs
index a3d11f23..217ab84e 100644
--- a/test/Renci.SshNet.Tests/Classes/SshCommandTest_Dispose.cs
+++ b/test/Renci.SshNet.Tests/Classes/SshCommandTest_Dispose.cs
@@ -83,7 +83,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void RaisingErrorOccuredOnSessionShouldDoNothing()
+ public void RaisingErrorOccurredOnSessionShouldDoNothing()
{
_sessionMock.Raise(s => s.ErrorOccured += null, new ExceptionEventArgs(new Exception()));
}
diff --git a/test/Renci.SshNet.Tests/Classes/SubsystemSession_Connect_SendSubsystemRequestFails.cs b/test/Renci.SshNet.Tests/Classes/SubsystemSession_Connect_SendSubsystemRequestFails.cs
index 3df4c98c..8e5a7b5f 100644
--- a/test/Renci.SshNet.Tests/Classes/SubsystemSession_Connect_SendSubsystemRequestFails.cs
+++ b/test/Renci.SshNet.Tests/Classes/SubsystemSession_Connect_SendSubsystemRequestFails.cs
@@ -107,7 +107,7 @@ namespace Renci.SshNet.Tests.Classes
}
[TestMethod]
- public void ErrorOccuredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnSubsystemSession()
+ public void ErrorOccurredOnSessionShouldNoLongerBeSignaledViaErrorOccurredOnSubsystemSession()
{
_sessionMock.Raise(p => p.ErrorOccured += null, new ExceptionEventArgs(new Exception()));
diff --git a/src/Renci.SshNet/ForwardedPort.cs b/src/Renci.SshNet/ForwardedPort.cs
index c19ef31b..6440c747 100644
--- a/src/Renci.SshNet/ForwardedPort.cs
+++ b/src/Renci.SshNet/ForwardedPort.cs
@@ -64,7 +64,7 @@ namespace Renci.SshNet
throw new SshConnectionException("Client not connected.");
}
- Session.ErrorOccured += Session_ErrorOccured;
+ Session.ErrorOccured += Session_ErrorOccurred;
StartPort();
}
@@ -107,7 +107,7 @@ namespace Renci.SshNet
var session = Session;
if (session is not null)
{
- session.ErrorOccured -= Session_ErrorOccured;
+ session.ErrorOccured -= Session_ErrorOccurred;
}
}
@@ -162,11 +162,11 @@ namespace Renci.SshNet
}
///
/// Handles session ErrorOccured event.
///
/// The source of the event.
/// The instance containing the event data.
- private void Session_ErrorOccured(object sender, ExceptionEventArgs e)
+ private void Session_ErrorOccurred(object sender, ExceptionEventArgs e)
{
RaiseExceptionEvent(e.Exception);
}
@@ -162,11 +162,11 @@ namespace Renci.SshNet
}
///
- /// Handles session ErrorOccured event.
+ /// Handles session ErrorOccurred event.
///
/// The source of the event.